/*
    GQ -- a GTK-based LDAP client
    Copyright (C) 1998-2001 Bert Vermeulen

    This program is released under the Gnu General Public License with
    the additional exemption that compiling, linking, and/or using
    OpenSSL is allowed.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


#include <gtk/gtk.h>

#include "gq.h"
#include "mainwin.h"
#include "configfile.h"


GdkFont *big_fixed;

int main(int argc, char *argv[])
{

     gtk_set_locale();
     gtk_init(&argc, &argv);

     init_config();

     setup_fonts();
     create_mainwin();

     gtk_main ();

     return(0);
}


void setup_fonts(void)
{

     big_fixed = gdk_font_load(FONT_BIG_FIXED);

}

